IMStatusCode

Enum IMStatusCode 

pub enum IMStatusCode {
Show 30 variants Success = 0, Failure = 1, InvalidSubscription = 125, UnsupportedAccess = 126, UnsupportedEndpoint = 127, InvalidAction = 128, UnsupportedCommand = 129, InvalidCommand = 133, UnsupportedAttribute = 134, ConstraintError = 135, UnsupportedWrite = 136, ResourceExhausted = 137, NotFound = 139, UnreportableAttribute = 140, InvalidDataType = 141, UnsupportedRead = 143, DataVersionMismatch = 146, Timeout = 148, UnsupportedNode = 155, Busy = 156, UnsupportedCluster = 195, NoUpstreamSubscription = 197, NeedsTimedInteraction = 198, UnsupportedEvent = 199, PathsExhausted = 200, TimedRequestMisMatch = 201, FailSafeRequired = 202, InvalidInState = 203, NoCommandResponse = 204, DynamicConstraintError = 207,
}
An enumeration of all possible error codes that can be returned by the Interaction Model.

Variants



Success = 0



Failure = 1



InvalidSubscription = 125



UnsupportedAccess = 126



UnsupportedEndpoint = 127



InvalidAction = 128



UnsupportedCommand = 129



InvalidCommand = 133



UnsupportedAttribute = 134



ConstraintError = 135



UnsupportedWrite = 136



ResourceExhausted = 137



NotFound = 139



UnreportableAttribute = 140



InvalidDataType = 141



UnsupportedRead = 143



DataVersionMismatch = 146



Timeout = 148



UnsupportedNode = 155



Busy = 156



UnsupportedCluster = 195



NoUpstreamSubscription = 197



NeedsTimedInteraction = 198



UnsupportedEvent = 199



PathsExhausted = 200



TimedRequestMisMatch = 201



FailSafeRequired = 202



InvalidInState = 203



NoCommandResponse = 204



DynamicConstraintError = 207

Implementations

Source

impl IMStatusCode

pub fn to_error_code(self) -> Option<ErrorCode>

Convert a non-success IM status code to an ErrorCode.

Returns None for Success, since success is not an error.